<?php
/*
Plugin Name: Guitar Chords and Tabs
Plugin URI: http://jtab.tardate.com/
Description: UI to display guitar chords and tab on your WordPress blog, based on the jTab JavaScript library by Paul Gallagher.
Version: 1.2
Author: jeromeBourdais, PaulGallagher, MatthewMarichiba
Author URI: http://jerome.bourdais.info
*/

/* This file Copyright 2014  jeromeBourdais  (email : jerome atsign bourdais dot info)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

if ( ! defined( 'ABSPATH' ) )
	die( "Can't load this file directly" );

class GuitarChordsTabs
{
	function __construct() {
		add_action( 'admin_init', array( $this, 'action_admin_init' ) );
	}
	
	function action_admin_init() {
		// only hook up these filters if we're in the admin panel, and the current user has permission
		// to edit posts and pages
		if ( current_user_can( 'edit_posts' ) && current_user_can( 'edit_pages' ) ) {
			add_filter( 'mce_buttons', array( $this, 'filter_mce_button' ) );
			add_filter( 'mce_external_plugins', array( $this, 'filter_mce_plugin' ) );
		}
	}
	
	function filter_mce_button( $buttons ) {
		// add a separation before our button
		array_push( $buttons, '|', 'mygct_button');
		return $buttons;
	}
	
	function filter_mce_plugin( $plugins ) {
		// this plugin file will work the magic of our button
		$plugins['mygct'] = plugin_dir_url( __FILE__ ) . 'js/guitar-chords-and-tabs.js';
		return $plugins;
	}
}

$mygct = new GuitarChordsTabs();


/**************************
 *  plugin jTab SHORTCODE *
 **************************/
function jtab_shortcode($atts)    
  {
    if (!isset($atts['phrase'])) {$atts['phrase']="";}
	if (!isset($atts['class'])) {$atts['class']="";}
    if (!isset($atts['buttontext'])) {$atts['buttontext']="jTab this!";}
    if (!isset($atts['id'])) {
        $id_string="";
    } else {
        $id_string=" div='" . $atts['id'] . "' "; 
    }
    if (!isset($atts['showform'])) {
        $atts['showform']="false";
    } elseif ($atts['showform'] == 'true') { // if showform is set and it's 'true', then force the div id='jtab' 
        $id_string=" id='jtab' ";
    }

	// Model output to look like the following:
	// <div class="jtab optionalclass" id="optionalid"> E / / / | Am / B / || </div> 
	// Here's a good phrase to try: A x.0.2.2.3.0 $2 2 0 2 3 5/3 A B Cdim
	$embed_string =
		'<div class=\'jtab ' . $atts['class'] . '\' ' . $id_string . '>' . $atts['phrase'] . '</div>';
    if ($atts['showform'] == 'true') {
        $embed_string = '
            <input id="jtab_phrase" type="text" size="40" value="' . $atts['phrase'] . '">
            <input id="jtab_button" type="button" value="' . $atts['buttontext'] . '">
            ' . $embed_string;
    }


	if ( isset($atts['debug']) ) {
	    $embed_string = $embed_string . "<br>Here are the parameters:<br> phrase=".$atts['phras']." showform=".$atts['showform']." class=".$atts['class']." id_string=".$id_string. " debug=".$atts['debug']."<br>";
    } 
	return $embed_string;  
}
add_shortcode("jtab", "jtab_shortcode");

/** 
 * include_jtab_js() loads a javascript file in the footer section of a page. 
 * This function is an action hook for wp_foot (or wp_head). 
 */
function include_jtab_js () {
        
    // register the javascript location, dependencies and version
    // MJM: This code copied from WP codex: http://codex.wordpress.org/Function_Reference/wp_enqueue_script
    $custom_script_path = WP_PLUGIN_URL . '/' . 
        str_replace(basename(__FILE__), "", plugin_basename(__FILE__) ) . 'jtab/javascripts/';

    wp_register_script('jtab_prototype', $custom_script_path . "prototype.js", array('jquery'), false, true ); // args: $handle, $path_to_source, $dependencies, $version, $in_footer
    wp_enqueue_script('jtab_prototype');
    wp_register_script('jtab_raphael', $custom_script_path . "raphael.js", array('jquery'), false, true ); 
    wp_enqueue_script('jtab_raphael');
    wp_register_script('jtab_jtab', $custom_script_path . "jtab.js", array('jquery'), false, true ); 
    wp_enqueue_script('jtab_jtab');
    wp_register_script('jtab_form', $custom_script_path . "../../js/scripts.js", array('jquery'), false, true ); 
    wp_enqueue_script('jtab_form');
}
add_action('wp_enqueue_scripts', 'include_jtab_js');

/** 
 * include_jtab_js_edit_post() add js in Edit Post
 * This function is an action hook for wp_foot (or wp_head). 
 */
 function include_jtab_js_edit_post() {

    global $parent_file;

    if ( isset( $_GET['action'] ) && $_GET['action'] == 'edit' && isset( $_GET['post'] ) && $parent_file == 'edit.php') {
		 $custom_script_path = WP_PLUGIN_URL . '/' . str_replace(basename(__FILE__), "", plugin_basename(__FILE__) ) . 'jtab/javascripts/';

		wp_register_script('jtab_prototype', $custom_script_path . "prototype.js", array('jquery'), false, true ); // args: $handle, $path_to_source, $dependencies, $version, $in_footer
		wp_enqueue_script('jtab_prototype');
		wp_register_script('jtab_raphael', $custom_script_path . "raphael.js", array('jquery'), false, true ); 
		wp_enqueue_script('jtab_raphael');
		wp_register_script('jtab_jtab', $custom_script_path . "jtab.js", array('jquery'), false, true ); 
		wp_enqueue_script('jtab_jtab');
		wp_register_script('jtab_form', $custom_script_path . "../../js/scripts.js", array('jquery'), false, true ); 
		wp_enqueue_script('jtab_form');
	}
}
add_filter('admin_head', 'include_jtab_js_edit_post');

/***************
 * Register style sheet. insertion custom CSS
 */
function register_plugin_styles() {
	wp_register_style( 'guitar-chords-and-tabs', plugins_url( 'guitar-chords-and-tabs/css/jtab.css' ) );
	wp_enqueue_style( 'guitar-chords-and-tabs' );
}
add_action( 'wp_enqueue_scripts', 'register_plugin_styles' );
// ********************





